pub fn check_outdated(
state: &PluginState,
index: &RegistryIndex,
) -> Vec<(String, String, String)>Expand description
Check which installed plugins have updates available in the registry.
pub fn check_outdated(
state: &PluginState,
index: &RegistryIndex,
) -> Vec<(String, String, String)>Check which installed plugins have updates available in the registry.