DiscoveredPlugin

Struct DiscoveredPlugin 

pub struct DiscoveredPlugin {
    pub manifest: PluginManifest,
    pub wasm_path: PathBuf,
    pub dev_mode: bool,
}
A plugin discovered on disk, ready to be loaded as a WasmTool.

Fields

manifest: PluginManifestwasm_path: PathBufdev_mode: bool

Whether this plugin was found in a development directory (CWD/plugins/).