pub struct RegistryEntry {
pub id: String,
pub description: String,
pub category: String,
pub author: String,
pub repository: String,
pub latest: String,
pub versions: Vec<RegistryVersionEntry>,
}Expand description
An entry in the registry index representing one plugin.
Fields
id: Stringdescription: Stringcategory: Stringrepository: Stringlatest: Stringversions: Vec<RegistryVersionEntry>Implementations
Sourceimpl RegistryEntry
impl RegistryEntry
Sourcepub fn latest_version(&self) -> Option<&RegistryVersionEntry>
pub fn latest_version(&self) -> Option<&RegistryVersionEntry>
Get the latest version entry.
Sourcepub fn has_update(&self, current: &str) -> bool
pub fn has_update(&self, current: &str) -> bool
Check whether a newer version exists compared to current.