pub struct DiscoveredPlugin {
pub manifest: PluginManifest,
pub wasm_path: PathBuf,
pub dev_mode: bool,
}Expand description
A plugin discovered on disk, ready to be loaded as a WasmTool.
Fields
manifest: PluginManifestwasm_path: PathBufdev_mode: boolWhether this plugin was found in a development directory (CWD/plugins/).